@@ -5,7 +5,7 @@ from aurora import Model
 class ModelName(Model):
 
     # Model columns
-    id = Model.column(datatype='integer', not_null=True)
+    id = Model.column(datatype='int', size='md', not_null=True)
 
     # Model constructor
     def __init__(self):
